@@ -21,6 +21,7 @@ class Write(Block):
     exec: str = None           # Set execute rights to 'u' (user), 'g' (group), 'o' (others). Can be 'uo' (user+others) and the same as `chmod uo+x file`.
     user: str = None           # Set user for a file.
     group: str = None          # Set group for a file.
+    format: dict = None        # Format block text using `str.format(**format)`.
     verbose: bool = False      # Print info about actions.
     shebang: str = None        # Put here the shebang. It's workaround for https://github.com/xonsh/xonsh/issues/4207
 
@@ -34,7 +35,7 @@ class Write(Block):
         return ' '.join(list(map(''.join, zip(*[iter(stat.filemode(st_mode)[1:])]*3))))
 
     def __enter__(self):
-        fp = Path(self.filepath)
+        fp = Path(self.filepath).expanduser()
 
         replaced, prev_st_mode, prev_user, prev_group = False, None, None, None
         if fp.exists():
@@ -52,10 +53,20 @@ class Write(Block):
             self.log(f'Make directories: {fp.parent}')
             fp.parent.mkdir(parents=True)
 
+            
+        macro_block = self.macro_block.strip()    
+        if self.format is not None:
+            self.log(f'Format block using {repr(self.format)}')
+            macro_block = macro_block.format(**self.format)
 
+        if self.shebang is not None:
+            shebang = self.shebang.strip()
+            self.log(f'Add shebang: {shebang}')
+            macro_block = shebang + '\n' + macro_block
+            
         self.log(f'Write to file: {fp}')
         with open(fp, self.mode) as f:
-            f.write((self.shebang.strip() + '\n' if self.shebang is not None else '') + self.macro_block.strip()+'\n')
+            f.write(macro_block + '\n')
 
 
         if self.replace_keep in ['m', 'a']:
